--- /dev/null	Tue Feb 13 07:11:52 2018
+++ new/usr/src/lib/libc/port/regex/tre.h	Tue Feb 13 07:11:52 2018
@@ -0,0 +1,95 @@
+/*
+ * Copyright (c) 2001-2009 Ville Laurikari <vl@iki.fi>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS
+ * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT
+ * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef _TRE_H
+#define	_TRE_H
+
+#include <sys/types.h>
+
+#include <locale.h>
+#include <wchar.h>
+#include <xlocale.h>
+
+#include "../../../../head/regex.h"
+
+#define	RE_MAGIC ((('r'^0200)<<8) | 'e')
+
+typedef int reg_errcode_t;
+
+enum {
+  TRE_CONFIG_APPROX,
+  TRE_CONFIG_WCHAR,
+  TRE_CONFIG_MULTIBYTE,
+  TRE_CONFIG_SYSTEM_ABI,
+  TRE_CONFIG_VERSION
+};
+
+typedef wchar_t tre_char_t;
+
+/* Approximate matching parameter struct. */
+typedef struct {
+  int cost_ins;		/* Default cost of an inserted character. */
+  int cost_del;		/* Default cost of a deleted character. */
+  int cost_subst;	/* Default cost of a substituted character. */
+  int max_cost;		/* Maximum allowed cost of a match. */
+
+  int max_ins;		/* Maximum allowed number of inserts. */
+  int max_del;		/* Maximum allowed number of deletes. */
+  int max_subst;	/* Maximum allowed number of substitutes. */
+  int max_err;		/* Maximum allowed number of errors total. */
+} regaparams_t;
+
+/* Approximate matching result struct. */
+typedef struct {
+  size_t nmatch;	/* Length of pmatch[] array. */
+  regmatch_t *pmatch;	/* Submatch data. */
+  int cost;		/* Cost of the match. */
+  int num_ins;		/* Number of inserts in the match. */
+  int num_del;		/* Number of deletes in the match. */
+  int num_subst;	/* Number of substitutes in the match. */
+} regamatch_t;
+
+typedef struct {
+  int (*get_next_char)(tre_char_t *c, unsigned int *pos_add, void *context);
+  void (*rewind)(size_t pos, void *context);
+  int (*compare)(size_t pos1, size_t pos2, size_t len, void *context);
+  void *context;
+} tre_str_source;
+
+#define	REG_ENHANCED			0x100000
+#define	REG_MINIMAL			0x200000
+#define	REG_UNGREEDY			0x200000
+
+#define	__DECONST(type, var) ((type)(uintptr_t)(const void *)(var))
+
+#ifndef	MB_CUR_MAX_L
+unsigned char __mb_cur_max_l(locale_t);
+#define	 MB_CUR_MAX_L(l) (__mb_cur_max_l(l))
+#endif
+
+#endif /* _TRE_H */
